@@ -10,11 +10,11 @@ EXTENSIONS = {
     'asar': {'binary', 'asar'},
     'bash': {'text', 'shell', 'bash'},
     'bat': {'text', 'batch'},
+    'bib': {'text', 'bib'},
     'bmp': {'binary', 'image', 'bitmap'},
     'bz2': {'binary', 'bzip2'},
     'c': {'text', 'c'},
     'cc': {'text', 'c++'},
-    'cu': {'text', 'cuda'},
     'cfg': {'text'},
     'chs': {'text', 'c2hs'},
     'clj': {'text', 'clojure'},
@@ -27,10 +27,12 @@ EXTENSIONS = {
     'cpp': {'text', 'c++'},
     'crt': {'text', 'pem'},
     'cs': {'text', 'c#'},
+    'csproj': {'text', 'xml', 'csproj'},
     'csh': {'text', 'shell', 'csh'},
     'cson': {'text', 'cson'},
     'css': {'text', 'css'},
     'csv': {'text', 'csv'},
+    'cu': {'text', 'cuda'},
     'cxx': {'text', 'c++'},
     'dart': {'text', 'dart'},
     'def': {'text', 'def'},
@@ -89,6 +91,7 @@ EXTENSIONS = {
     'key': {'text', 'pem'},
     'kml': {'text', 'kml', 'xml'},
     'kt': {'text', 'kotlin'},
+    'lean': {'text', 'lean'},
     'less': {'text', 'less'},
     'lhs': {'text', 'literate-haskell'},
     'libsonnet': {'text', 'jsonnet'},
@@ -130,31 +133,33 @@ EXTENSIONS = {
     'proto': {'text', 'proto'},
     'puml': {'text', 'plantuml'},
     'purs': {'text', 'purescript'},
+    'pxd': {'text', 'cython'},
+    'pxi': {'text', 'cython'},
     'py': {'text', 'python'},
     'pyi': {'text', 'pyi'},
     'pyx': {'text', 'cython'},
     'pyz': {'binary', 'pyz'},
     'pyzw': {'binary', 'pyz'},
-    'pxd': {'text', 'cython'},
-    'pxi': {'text', 'cython'},
     'r': {'text', 'r'},
     'rb': {'text', 'ruby'},
     'rs': {'text', 'rust'},
     'rst': {'text', 'rst'},
     's': {'text', 'asm'},
+    'sass': {'text', 'sass'},
     'sbt': {'text', 'sbt', 'scala'},
     'sc': {'text', 'scala'},
     'scala': {'text', 'scala'},
-    'scss': {'text', 'scss'},
     'scm': {'text', 'scheme'},
+    'scss': {'text', 'scss'},
     'sh': {'text', 'shell'},
+    'sln': {'text', 'sln'},
     'sls': {'text', 'salt'},
     'so': {'binary'},
     'sol': {'text', 'solidity'},
     'spec': {'text', 'spec'},
+    'sql': {'text', 'sql'},
     'ss': {'text', 'scheme'},
     'styl': {'text', 'stylus'},
-    'sql': {'text', 'sql'},
     'sv': {'text', 'system-verilog'},
     'svg': {'text', 'image', 'svg', 'xml'},
     'svh': {'text', 'system-verilog'},
@@ -163,15 +168,17 @@ EXTENSIONS = {
     'swiftdeps': {'text', 'swiftdeps'},
     'tac': {'text', 'twisted', 'python'},
     'tar': {'binary', 'tar'},
+    'tex': {'text', 'tex'},
+    'tf': {'text', 'terraform'},
+    'tfvars': {'text', 'terraform'},
     'tgz': {'binary', 'gzip'},
     'thrift': {'text', 'thrift'},
     'tiff': {'binary', 'image', 'tiff'},
     'toml': {'text', 'toml'},
-    'tf': {'text', 'terraform'},
-    'tfvars': {'text', 'terraform'},
     'ts': {'text', 'ts'},
     'tsx': {'text', 'tsx'},
     'ttf': {'binary', 'ttf'},
+    'txsprofile': {'text', 'ini', 'txsprofile'},
     'txt': {'text', 'plain-text'},
     'v': {'text', 'verilog'},
     'vdx': {'text', 'vdx'},
@@ -181,11 +188,13 @@ EXTENSIONS = {
     'vue': {'text', 'vue'},
     'war': {'binary', 'zip', 'jar'},
     'wav': {'binary', 'audio', 'wav'},
-    'wkt': {'text', 'wkt'},
+    'webp': {'binary', 'image', 'webp'},
     'whl': {'binary', 'wheel', 'zip'},
+    'wkt': {'text', 'wkt'},
     'woff': {'binary', 'woff'},
     'woff2': {'binary', 'woff2'},
     'wsgi': {'text', 'wsgi', 'python'},
+    'xhtml': {'text', 'xml', 'html', 'xhtml'},
     'xml': {'text', 'xml'},
     'xq': {'text', 'xquery'},
     'xql': {'text', 'xquery'},
@@ -209,30 +218,32 @@ EXTENSIONS_NEED_BINARY_CHECK = {
 
 NAMES = {
     '.babelrc': EXTENSIONS['json'] | {'babelrc'},
-    '.bashrc': EXTENSIONS['bash'],
     '.bash_aliases': EXTENSIONS['bash'],
     '.bash_profile': EXTENSIONS['bash'],
+    '.bashrc': EXTENSIONS['bash'],
     '.bowerrc': EXTENSIONS['json'] | {'bowerrc'},
     '.coveragerc': EXTENSIONS['ini'] | {'coveragerc'},
     '.cshrc': EXTENSIONS['csh'],
     '.dockerignore': {'text', 'dockerignore'},
     '.editorconfig': {'text', 'editorconfig'},
-    '.gitconfig': EXTENSIONS['ini'] | {'gitconfig'},
-    '.hgrc': EXTENSIONS['ini'] | {'hgrc'},
+    '.flake8': EXTENSIONS['ini'] | {'flake8'},
     '.gitattributes': {'text', 'gitattributes'},
+    '.gitconfig': EXTENSIONS['ini'] | {'gitconfig'},
     '.gitignore': {'text', 'gitignore'},
     '.gitmodules': {'text', 'gitmodules'},
+    '.hgrc': EXTENSIONS['ini'] | {'hgrc'},
     '.jshintrc': EXTENSIONS['json'] | {'jshintrc'},
     '.mailmap': {'text', 'mailmap'},
     '.mention-bot': EXTENSIONS['json'] | {'mention-bot'},
     '.npmignore': {'text', 'npmignore'},
     '.pdbrc': EXTENSIONS['py'] | {'pdbrc'},
     '.pypirc': EXTENSIONS['ini'] | {'pypirc'},
+    '.rstcheck.cfg': EXTENSIONS['ini'],
     '.yamllint': EXTENSIONS['yaml'] | {'yamllint'},
     '.zshrc': EXTENSIONS['zsh'],
     'AUTHORS': EXTENSIONS['txt'],
-    'BUILD.bazel': {'text', 'bazel'},
     'BUILD': {'text', 'bazel'},
+    'BUILD.bazel': {'text', 'bazel'},
     'CMakeLists.txt': EXTENSIONS['cmake'],
     'COPYING': EXTENSIONS['txt'],
     'Dockerfile': {'text', 'dockerfile'},
